//
// Copyright (c) Microsoft. All rights reserved.
// See https://aka.ms/azai/vision/license for the full license information.
//

#pragma once
#include <vision_api_cxx_common.h>
#include <vision_api_cxx_details_result_event_args_base.h>

namespace Azure {
namespace AI {
namespace Vision {
namespace ImageAnalysis {

/// <summary>
/// Represents an asynchronous Image Analysis result payload as an event argument.
/// </summary>
class ImageAnalysisEventArgs : private Core::Details::ResultEventArgsBase<ImageAnalysisResult, int>
{
private:

    using BaseResultEventArgs = Core::Details::ResultEventArgsBase<ImageAnalysisResult, int>;

public:

    /// <summary>
    /// Gets the Image Analysis result associated with this event.
    /// </summary>
    /// <returns>The ImageAnalysisResult wrapped inside a std::shared_ptr</returns>
    std::shared_ptr<ImageAnalysisResult> GetResult() const { return BaseResultEventArgs::GetResult(); }

protected:
     /*! \cond PROTECTED */
    static std::shared_ptr<ImageAnalysisEventArgs> FromHandle(AZAC_HANDLE handle)
    {
        auto ptr = new ImageAnalysisEventArgs(handle);
        return std::shared_ptr<ImageAnalysisEventArgs>(ptr);
    }

    explicit ImageAnalysisEventArgs(AZAC_HANDLE eventArgs) : ResultEventArgsBase(eventArgs)
    {
    }
    /*! \endcond */

private:

    AZAC_DISABLE_DEFAULT_CTORS(ImageAnalysisEventArgs);
};

} } } } // Azure::AI::Vision::ImageAnalysis
