//
// Copyright (c) Microsoft. All rights reserved.
// See https://aka.ms/azai/vision/license for the full license information.
//

#pragma once
#include <vision_api_cxx_common.h>

namespace Azure {
namespace AI {
namespace Vision {
namespace ImageAnalysis {

/// <summary>
/// Enums used to identify Image Analysis options in the AdvancedOptions class.
/// Do not use any of these values directly, instead use the appropriate Set and Get methods
/// on the ImageAnalysisOptions class (e.g. ImageAnalysisOptions::SetVisualFeatures).
/// </summary>
enum class ImageAnalysisOption
{
    /// <summary>
    /// A string property holding a list of visual features to analyze. Multiple values should be comma-separated.
    /// Valid feature types include: tags, objects, description, read, smartCrops, people.
    /// </summary>
    VisualFeatures = 1,

    /// <summary>
    /// Optional string property holding the desired language for output generation.
    /// If this parameter is not specified, the default value is \"en\".
    /// See https://aka.ms/cv-languages for a list of supported languages."
    /// </summary>
    Language,

    /// <summary>
    /// Optional string property holding the specify the version of the AI model, or \"latest\"
    /// to use the latest available model. Defaults to \"latest\".
    /// </summary>
    ModelVersion,

    /// <summary>
    /// Optional string property holding a list of aspect ratios to use for smart cropping.
    /// Aspect ratios are be calculated by dividing the target crop width by the height.
    /// Multiple values should be comma-separated.",
    /// </summary>
    CroppingAspectRatios,

    /// <summary>
    /// Optional string property, set to \"yes\" or \"no\". If \"yes\", the words \"Man/Woman\"
    /// will be replaced by \"Person\", and \"Boy/Girl\" will be replaced by \"Child\".
    /// If \"no\", the caption will have gendered terms. Defaults to \"no\".
    /// </summary>
    GenderNeutralCaption
};

} } } } // Azure::AI::Vision::ImageAnalysis

PRIVATE_PROPERTY_COLLECTION_STATICS(Azure::AI::Vision::ImageAnalysis::ImageAnalysisOption, "image.analysis.options")
