//
// Copyright (c) Microsoft. All rights reserved.
// See https://aka.ms/azai/vision/license for the full license information.
//

#pragma once
#include <vision_api_cxx_common.h>

namespace Azure {
namespace AI {
namespace Vision {
namespace ImageAnalysis {

/// <summary>
/// Represents the reasons why an Image Analysis operation concluded.
/// </summary>
enum class ImageAnalysisResultReason
{
    /*
    * Internal implementation note: this *DOES NOT* map directly to the "result reason" enumerations in core, as
    * here we merge the concept of stop reason and result reason together (as there's no "stop" for IA).
    *
    * See the Details namespace for the direct core mappings used to produce these.
    */

    /// <summary>
    /// Indicates that a result was generated due to an error during Image Analysis.
    /// </summary>
    /// <remarks>
    /// More information about the error can be obtained by creating an ImageAnalysisErrorDetails object,
    /// by calling ImageAnalysisErrorDetails::FromResult(), and passing in the result.
    /// </remarks>
    Error = 1,

    /// <summary>
    /// Indicates that Image Analysis was successful and results are available.
    /// </summary>
    Analyzed = 2
};

} } } } // Azure::AI::Vision::ImageAnalysis
